@@ -1,4 +1,5 @@
 from servicecatalog_puppet import constants
+from servicecatalog_puppet.workflow.generate import generate_shares_task
 
 
 def generate_dependency_tasks(
@@ -11,11 +12,42 @@ def generate_dependency_tasks(
 ):
     is_running_in_hub = execution_mode != constants.EXECUTION_MODE_SPOKE
 
-    from servicecatalog_puppet.workflow import codebuild_runs
-    from servicecatalog_puppet.workflow import launch
-    from servicecatalog_puppet.workflow import spoke_local_portfolios
-    from servicecatalog_puppet.workflow import assertions
-    from servicecatalog_puppet.workflow import lambda_invocations
+    from servicecatalog_puppet.workflow.launch import (
+        launch_task,
+        launch_for_account_task,
+        launch_for_region_task,
+        launch_for_account_and_region_task,
+    )
+    from servicecatalog_puppet.workflow.stack import (
+        stack_task,
+        stack_for_account_task,
+        stack_for_region_task,
+        stack_for_account_and_region_task,
+    )
+    from servicecatalog_puppet.workflow.spoke_local_portfolios import (
+        spoke_local_portfolio_task,
+        spoke_local_portfolio_for_account_task,
+        spoke_local_portfolio_for_region_task,
+        spoke_local_portfolio_for_account_and_region_task,
+    )
+    from servicecatalog_puppet.workflow.assertions import (
+        assertion_task,
+        assertion_for_account_task,
+        assertion_for_region_task,
+        assertion_for_account_and_region_task,
+    )
+    from servicecatalog_puppet.workflow.codebuild_runs import (
+        code_build_run_task,
+        code_build_run_for_account_task,
+        code_build_run_for_region_task,
+        code_build_run_for_account_and_region_task,
+    )
+    from servicecatalog_puppet.workflow.lambda_invocations import (
+        lambda_invocation_task,
+        lambda_invocation_for_account_task,
+        lambda_invocation_for_region_task,
+        lambda_invocation_for_account_and_region_task,
+    )
 
     these_dependencies = list()
     common_args = dict(
@@ -25,13 +57,13 @@ def generate_dependency_tasks(
         if depends_on.get("type") == constants.LAUNCH:
             if depends_on.get(constants.AFFINITY) == constants.LAUNCH:
                 these_dependencies.append(
-                    launch.LaunchTask(
+                    launch_task.LaunchTask(
                         **common_args, launch_name=depends_on.get("name"),
                     )
                 )
             if depends_on.get(constants.AFFINITY) == "account":
                 these_dependencies.append(
-                    launch.LaunchForAccountTask(
+                    launch_for_account_task.LaunchForAccountTask(
                         **common_args,
                         launch_name=depends_on.get("name"),
                         account_id=account_id,
@@ -39,7 +71,7 @@ def generate_dependency_tasks(
                 )
             if depends_on.get(constants.AFFINITY) == "region":
                 these_dependencies.append(
-                    launch.LaunchForRegionTask(
+                    launch_for_region_task.LaunchForRegionTask(
                         **common_args,
                         launch_name=depends_on.get("name"),
                         region=region,
@@ -47,7 +79,7 @@ def generate_dependency_tasks(
                 )
             if depends_on.get(constants.AFFINITY) == "account-and-region":
                 these_dependencies.append(
-                    launch.LaunchForAccountAndRegionTask(
+                    launch_for_account_and_region_task.LaunchForAccountAndRegionTask(
                         **common_args,
                         launch_name=depends_on.get("name"),
                         account_id=account_id,
@@ -55,20 +87,51 @@ def generate_dependency_tasks(
                     )
                 )
 
+        elif depends_on.get("type") == constants.STACK:
+            if depends_on.get(constants.AFFINITY) == constants.STACK:
+                these_dependencies.append(
+                    stack_task.StackTask(
+                        **common_args, stack_name=depends_on.get("name"),
+                    )
+                )
+            if depends_on.get(constants.AFFINITY) == "account":
+                these_dependencies.append(
+                    stack_for_account_task.StackForAccountTask(
+                        **common_args,
+                        stack_name=depends_on.get("name"),
+                        account_id=account_id,
+                    )
+                )
+            if depends_on.get(constants.AFFINITY) == "region":
+                these_dependencies.append(
+                    stack_for_region_task.StackForRegionTask(
+                        **common_args, stack_name=depends_on.get("name"), region=region,
+                    )
+                )
+            if depends_on.get(constants.AFFINITY) == "account-and-region":
+                these_dependencies.append(
+                    stack_for_account_and_region_task.StackForAccountAndRegionTask(
+                        **common_args,
+                        stack_name=depends_on.get("name"),
+                        account_id=account_id,
+                        region=region,
+                    )
+                )
+
         elif (
             is_running_in_hub
             and depends_on.get("type") == constants.SPOKE_LOCAL_PORTFOLIO
         ):
             if depends_on.get(constants.AFFINITY) == constants.SPOKE_LOCAL_PORTFOLIO:
                 these_dependencies.append(
-                    spoke_local_portfolios.SpokeLocalPortfolioTask(
+                    spoke_local_portfolio_task.SpokeLocalPortfolioTask(
                         **common_args,
                         spoke_local_portfolio_name=depends_on.get("name"),
                     )
                 )
             if depends_on.get(constants.AFFINITY) == "account":
                 these_dependencies.append(
-                    spoke_local_portfolios.SpokeLocalPortfolioForAccountTask(
+                    spoke_local_portfolio_for_account_task.SpokeLocalPortfolioForAccountTask(
                         **common_args,
                         spoke_local_portfolio_name=depends_on.get("name"),
                         account_id=account_id,
@@ -76,7 +139,7 @@ def generate_dependency_tasks(
                 )
             if depends_on.get(constants.AFFINITY) == "region":
                 these_dependencies.append(
-                    spoke_local_portfolios.SpokeLocalPortfolioForRegionTask(
+                    spoke_local_portfolio_for_region_task.SpokeLocalPortfolioForRegionTask(
                         **common_args,
                         spoke_local_portfolio_name=depends_on.get("name"),
                         region=region,
@@ -84,24 +147,23 @@ def generate_dependency_tasks(
                 )
             if depends_on.get(constants.AFFINITY) == "account-and-region":
                 these_dependencies.append(
-                    spoke_local_portfolios.SpokeLocalPortfolioForAccountAndRegionTask(
+                    spoke_local_portfolio_for_account_and_region_task.SpokeLocalPortfolioForAccountAndRegionTask(
                         **common_args,
                         spoke_local_portfolio_name=depends_on.get("name"),
                         account_id=account_id,
                         region=region,
                     )
                 )
-
         elif is_running_in_hub and depends_on.get("type") == constants.ASSERTION:
             if depends_on.get(constants.AFFINITY) == constants.ASSERTION:
                 these_dependencies.append(
-                    assertions.AssertionTask(
+                    assertion_task.AssertionTask(
                         **common_args, assertion_name=depends_on.get("name"),
                     )
                 )
             if depends_on.get(constants.AFFINITY) == "account":
                 these_dependencies.append(
-                    assertions.AssertionForAccountTask(
+                    assertion_for_account_task.AssertionForAccountTask(
                         **common_args,
                         assertion_name=depends_on.get("name"),
                         account_id=account_id,
@@ -109,7 +171,7 @@ def generate_dependency_tasks(
                 )
             if depends_on.get(constants.AFFINITY) == "region":
                 these_dependencies.append(
-                    assertions.AssertionForRegionTask(
+                    assertion_for_region_task.AssertionForRegionTask(
                         **common_args,
                         assertion_name=depends_on.get("name"),
                         region=region,
@@ -117,7 +179,7 @@ def generate_dependency_tasks(
                 )
             if depends_on.get(constants.AFFINITY) == "account-and-region":
                 these_dependencies.append(
-                    assertions.AssertionForAccountAndRegionTask(
+                    assertion_for_account_and_region_task.AssertionForAccountAndRegionTask(
                         **common_args,
                         assertion_name=depends_on.get("name"),
                         account_id=account_id,
@@ -128,13 +190,13 @@ def generate_dependency_tasks(
         elif is_running_in_hub and depends_on.get("type") == constants.CODE_BUILD_RUN:
             if depends_on.get(constants.AFFINITY) == constants.CODE_BUILD_RUN:
                 these_dependencies.append(
-                    codebuild_runs.CodeBuildRunTask(
+                    code_build_run_task.CodeBuildRunTask(
                         **common_args, code_build_run_name=depends_on.get("name"),
                     )
                 )
             if depends_on.get(constants.AFFINITY) == "account":
                 these_dependencies.append(
-                    codebuild_runs.CodeBuildRunForAccountTask(
+                    code_build_run_for_account_task.CodeBuildRunForAccountTask(
                         **common_args,
                         code_build_run_name=depends_on.get("name"),
                         account_id=account_id,
@@ -142,7 +204,7 @@ def generate_dependency_tasks(
                 )
             if depends_on.get(constants.AFFINITY) == "region":
                 these_dependencies.append(
-                    codebuild_runs.CodeBuildRunForRegionTask(
+                    code_build_run_for_region_task.CodeBuildRunForRegionTask(
                         **common_args,
                         code_build_run_name=depends_on.get("name"),
                         region=region,
@@ -150,7 +212,7 @@ def generate_dependency_tasks(
                 )
             if depends_on.get(constants.AFFINITY) == "account-and-region":
                 these_dependencies.append(
-                    codebuild_runs.CodeBuildRunForAccountAndRegionTask(
+                    code_build_run_for_account_and_region_task.CodeBuildRunForAccountAndRegionTask(
                         **common_args,
                         code_build_run_name=depends_on.get("name"),
                         account_id=account_id,
@@ -163,13 +225,13 @@ def generate_dependency_tasks(
         ):
             if depends_on.get(constants.AFFINITY) == constants.LAMBDA_INVOCATION:
                 these_dependencies.append(
-                    lambda_invocations.LambdaInvocationTask(
+                    lambda_invocation_task.LambdaInvocationTask(
                         **common_args, lambda_invocation_name=depends_on.get("name"),
                     )
                 )
             if depends_on.get(constants.AFFINITY) == "account":
                 these_dependencies.append(
-                    lambda_invocations.LambdaInvocationForAccountTask(
+                    lambda_invocation_for_account_task.LambdaInvocationForAccountTask(
                         **common_args,
                         lambda_invocation_name=depends_on.get("name"),
                         account_id=account_id,
@@ -177,7 +239,7 @@ def generate_dependency_tasks(
                 )
             if depends_on.get(constants.AFFINITY) == "region":
                 these_dependencies.append(
-                    lambda_invocations.LambdaInvocationForRegionTask(
+                    lambda_invocation_for_region_task.LambdaInvocationForRegionTask(
                         **common_args,
                         lambda_invocation_name=depends_on.get("name"),
                         region=region,
@@ -185,7 +247,7 @@ def generate_dependency_tasks(
                 )
             if depends_on.get(constants.AFFINITY) == "account-and-region":
                 these_dependencies.append(
-                    lambda_invocations.LambdaInvocationForAccountAndRegionTask(
+                    lambda_invocation_for_account_and_region_task.LambdaInvocationForAccountAndRegionTask(
                         **common_args,
                         lambda_invocation_name=depends_on.get("name"),
                         account_id=account_id,
@@ -197,27 +259,10 @@ def generate_dependency_tasks(
 
 class DependenciesMixin(object):
     def get_section_dependencies(self):
-        from servicecatalog_puppet.workflow import codebuild_runs
-        from servicecatalog_puppet.workflow import launch
-        from servicecatalog_puppet.workflow import spoke_local_portfolios
-        from servicecatalog_puppet.workflow import assertions
-        from servicecatalog_puppet.workflow import lambda_invocations
-
-        from servicecatalog_puppet.workflow import generate
-
-        if isinstance(self, codebuild_runs.ExecuteCodeBuildRunTask):
-            item_name = self.code_build_run_name
-        elif isinstance(self, launch.ProvisioningTask):
-            item_name = self.launch_name
-        elif isinstance(self, spoke_local_portfolios.SpokeLocalPortfolioBaseTask):
-            item_name = self.spoke_local_portfolio_name
-        elif isinstance(self, assertions.AssertTask):
-            item_name = self.assertion_name
-        elif isinstance(self, lambda_invocations.InvokeLambdaTask):
-            item_name = self.lambda_invocation_name
-
         dependencies = (
-            self.manifest.get(self.section_name).get(item_name).get("depends_on", [])
+            self.manifest.get(self.section_name)
+            .get(self.item_name)
+            .get("depends_on", [])
         )
 
         should_generate_shares = not (
@@ -236,7 +281,7 @@ class DependenciesMixin(object):
         if self.section_name in [constants.SPOKE_LOCAL_PORTFOLIOS, constants.LAUNCHES]:
             if should_generate_shares:
                 these_dependencies.append(
-                    generate.GenerateSharesTask(
+                    generate_shares_task.GenerateSharesTask(
                         puppet_account_id=self.puppet_account_id,
                         manifest_file_path=self.manifest_file_path,
                         section=self.section_name,
